This package provides a class that can be inherited from to make your own simulation of a discrete stochastic process using the Gillespie algorithm.

* Install with ``pip3 install git+git://github.com/BPSB/OOGillespie`` or similar.
* `Documentation <https://oogillespie.readthedocs.io>`_
* `Issue Tracker <https://github.com/BPSB/OOGillespie/issues>`_ – Please report any bugs here. Also feel free to ask for new features.
